@@ -19,9 +19,8 @@
 #'
 #' @aliases wdnr.gis
 #'
-#' @docType package
 #' @name wdnr.gis-package
-NULL
+"_PACKAGE"
 
 ## quiets concerns of R CMD check re: the .'s that appear in pipelines
 if(getRversion() >= "2.15.1")  utils::globalVariables(c("."))
